@@ -53,6 +53,14 @@
 #include "personal-details.h"
 #include "opal-account.h"
 
+static void
+registration_event_in_main (sigc::slot2<void, Ekiga::AccountCore::RegistrationState, std::string> slot,
+			    Ekiga::AccountCore::RegistrationState state,
+			    const std::string msg)
+{
+  slot (state, msg);
+}
+
 static void
 presence_status_in_main (Ekiga::PresenceFetcher* fetcher,
                          std::string uri,
@@ -91,15 +99,15 @@ namespace Opal {
 
   public:
       subscriber (const Opal::Account & _account,
-                  Opal::Sip::EndPoint & _manager) 
+                  Opal::Sip::EndPoint & _manager)
         : PThread (1000, AutoDeleteThread),
         account (_account),
-        manager (_manager) 
+        manager (_manager)
       {
         this->Resume ();
       };
 
-      void Main () 
+      void Main ()
         {
           manager.Register (account);
         };
@@ -114,11 +122,11 @@ namespace Opal {
 
 
 /* The class */
-Opal::Sip::EndPoint::EndPoint (Opal::CallManager & _manager, 
-                               Ekiga::ServiceCore & _core, 
+Opal::Sip::EndPoint::EndPoint (Opal::CallManager & _manager,
+                               Ekiga::ServiceCore & _core,
                                unsigned _listen_port)
 :   SIPEndPoint (_manager),
-    manager (_manager), 
+    manager (_manager),
     core (_core)
 {
   gmref_ptr<Ekiga::ChatCore> chat_core = core.get ("chat-core");
@@ -129,9 +137,9 @@ Opal::Sip::EndPoint::EndPoint (Opal::CallManager & _manager,
     runtime = &*smart;
   }
   {
-    gmref_ptr<Ekiga::AccountCore> smart = core.get ("account-core");
+    gmref_ptr<Opal::Bank> smart = core.get ("opal-account-store");
     smart->reference (); // take a reference in the main thread
-    account_core = &*smart;
+    bank = &*smart;
   }
 
 
@@ -146,7 +154,7 @@ Opal::Sip::EndPoint::EndPoint (Opal::CallManager & _manager,
   /* Timeouts */
   SetAckTimeout (PTimeInterval (0, 32));
   SetPduCleanUpTimeout (PTimeInterval (0, 1));
-  SetInviteTimeout (PTimeInterval (0, 6));
+  SetInviteTimeout (PTimeInterval (0, 60));
   SetNonInviteTimeout (PTimeInterval (0, 6));
   SetRetryTimeouts (500, 4000);
   SetMaxRetries (8);
@@ -158,7 +166,7 @@ Opal::Sip::EndPoint::EndPoint (Opal::CallManager & _manager,
   SetUserAgent ("Ekiga/" PACKAGE_VERSION);
 
   /* Ready to take calls */
-  manager.AddRouteEntry("sip:.* = pc:<db>");
+  manager.AddRouteEntry("sip:.* = pc:*");
   manager.AddRouteEntry("pc:.* = sip:<da>");
 
   /* NAT Binding */
@@ -169,7 +177,7 @@ Opal::Sip::EndPoint::EndPoint (Opal::CallManager & _manager,
 Opal::Sip::EndPoint::~EndPoint ()
 {
   runtime->unreference (); // leave a reference in the main thread
-  account_core->unreference (); // leave a reference in the main thread
+  bank->unreference (); // leave a reference in the main thread
   dialect->unreference (); // leave a reference in the main thread
 }
 
@@ -205,41 +213,35 @@ bool Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
 
   if (uri.find ("@") == string::npos) {
 
-    gmref_ptr<Opal::Bank> bank = core.get ("opal-account-store");
+    for (Opal::Bank::iterator it = bank->begin ();
+	 it != bank->end ();
+	 it++) {
 
-    if (bank) {
+      if (it->get_protocol_name () == "SIP" && it->is_active ()) {
 
-      for (Opal::Bank::iterator it = bank->begin ();
-           it != bank->end ();
-           it++) {
+	std::stringstream uristr;
+	std::string str = uri;
 
-        if (it->get_protocol_name () == "SIP" && it->is_active ()) {
+	for (unsigned i = 0 ; i < str.length() ; i++) {
 
-          std::stringstream uristr;
-          std::string str = uri;
+	  if (str [i] == ' ' || str [i] == '-') {
+	    str.erase (i,1);
+	    i--;
+	  }
+	}
 
-          for (unsigned i = 0 ; i < str.length() ; i++) {
+	if (str.find ("sip:") == string::npos)
+	  uristr << "sip:" << str;
+	else
+	  uristr << str;
 
-            if (str [i] == ' ' || str [i] == '-') {
-              str.erase (i,1);
-              i--;
-            }
-          }
+	uristr << "@" << it->get_host ();
 
-          if (str.find ("sip:") == string::npos)
-            uristr << "sip:" << str;
-          else
-            uristr << str;
-
-          uristr << "@" << it->get_host ();
-
-          uris.push_back (uristr.str ());
-          accounts.push_back (it->get_name ());
-        }
+	uris.push_back (uristr.str ());
+	accounts.push_back (it->get_name ());
       }
     }
-  }
-  else {
+  } else {
     uris.push_back (uri);
     accounts.push_back ("");
   }
@@ -263,7 +265,7 @@ bool Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
     if (0 == GetConnectionCount ())
       builder.add_action ("call", call_action.str (),
                           sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_dial), (*it)));
-    else 
+    else
       builder.add_action ("transfer", transfer_action.str (),
                           sigc::bind (sigc::mem_fun (this, &Opal::Sip::EndPoint::on_transfer), (*it)));
 
@@ -276,7 +278,7 @@ bool Opal::Sip::EndPoint::menu_builder_add_actions (const std::string& fullname,
        it++) {
 
     std::stringstream msg_action;
-    if (!(*ita).empty ()) 
+    if (!(*ita).empty ())
       msg_action << _("Message") << " [" << (*ita) << "]";
     else
       msg_action << _("Message");
@@ -298,21 +300,21 @@ void Opal::Sip::EndPoint::fetch (const std::string _uri)
   std::string::size_type loc = _uri.find ("@", 0);
   std::string domain;
 
-  if (loc != string::npos) 
+  if (loc != string::npos)
     domain = _uri.substr (loc+1);
 
   // It is not in the list of uris for which a subscribe is active
   if (std::find (subscribed_uris.begin (), subscribed_uris.end (), _uri) == subscribed_uris.end ()) {
 
-    // We are registered yet
-    if (std::find (domains.begin (), domains.end (), domain) != domains.end ()) {
+    // The account is active
+    if (std::find (active_domains.begin (), active_domains.end (), domain) != active_domains.end ()) {
 
       Subscribe (SIPSubscribe::Presence, 300, PString (_uri.c_str ()));
       Subscribe (SIPSubscribe::Dialog, 300, PString (_uri.c_str ()));
       subscribed_uris.push_back (_uri);
     }
     else {
-     
+
       to_subscribe_uris.push_back (_uri);
     }
   }
@@ -348,7 +350,7 @@ void Opal::Sip::EndPoint::publish (const Ekiga::PersonalDetails & details)
     data += "\">\r\n";
 
     data += "<tuple id=\"";
-    data += to; 
+    data += to;
     data += "_on_";
     data += hostname;
     data += "\">\r\n";
@@ -374,12 +376,12 @@ void Opal::Sip::EndPoint::publish (const Ekiga::PersonalDetails & details)
     data += "</tuple>\r\n";
     data += "</presence>\r\n";
 
-    Publish (to, data, 500); // TODO: allow to change the 500 
+    Publish (to, data, 500); // TODO: allow to change the 500
   }
 }
 
 
-bool Opal::Sip::EndPoint::send_message (const std::string & _uri, 
+bool Opal::Sip::EndPoint::send_message (const std::string & _uri,
                                         const std::string & _message)
 {
   if (!_uri.empty () && (_uri.find ("sip:") == 0 || _uri.find (':') == string::npos) && !_message.empty ()) {
@@ -463,7 +465,7 @@ bool Opal::Sip::EndPoint::set_listen_port (unsigned port)
 
   manager.get_udp_ports (udp_min, udp_max);
 
-  if (port > 0 && port >= udp_min && port <= udp_max) {
+  if (port > 0) {
 
     std::stringstream str;
     RemoveListener (NULL);
@@ -484,8 +486,10 @@ bool Opal::Sip::EndPoint::set_listen_port (unsigned port)
         port++;
       }
     }
-    else
+    else {
       listen_iface.port = port;
+      return true;
+    }
   }
 
   return false;
@@ -537,9 +541,21 @@ unsigned Opal::Sip::EndPoint::get_nat_binding_delay ()
 }
 
 
+std::string Opal::Sip::EndPoint::get_aor_domain (const std::string & aor)
+{
+  std::string domain;
+  std::string::size_type loc = aor.find ("@", 0);
+
+  if (loc != string::npos)
+    domain = aor.substr (loc+1);
+
+  return domain;
+}
+
+
 bool Opal::Sip::EndPoint::subscribe (const Opal::Account & account)
 {
-  if (account.get_protocol_name () != "SIP" || account.is_active ())
+  if (account.get_protocol_name () != "SIP")
     return false;
 
   new subscriber (account, *this);
@@ -549,7 +565,7 @@ bool Opal::Sip::EndPoint::subscribe (const Opal::Account & account)
 
 bool Opal::Sip::EndPoint::unsubscribe (const Opal::Account & account)
 {
-  if (account.get_protocol_name () != "SIP" || !account.is_active ())
+  if (account.get_protocol_name () != "SIP")
     return false;
 
   new subscriber (account, *this);
@@ -566,7 +582,7 @@ void Opal::Sip::EndPoint::Register (const Opal::Account & account)
   if (loc != std::string::npos)
     host = host.substr (0, loc);
 
-  if (account.get_username ().find ("@") == std::string::npos) 
+  if (account.get_username ().find ("@") == std::string::npos)
     aor << account.get_username () << "@" << host;
   else
     aor << account.get_username ();
@@ -580,6 +596,15 @@ void Opal::Sip::EndPoint::Register (const Opal::Account & account)
   params.m_minRetryTime = 0;
   params.m_maxRetryTime = 0;
 
+  // Update the list of active domains
+  std::string domain = Opal::Sip::EndPoint::get_aor_domain (aor.str ());
+  bool found = (std::find (active_domains.begin (), active_domains.end (), domain) != active_domains.end ());
+  if (account.is_enabled () && !found)
+    active_domains.push_back (domain);
+  else if (!account.is_enabled () && found)
+    active_domains.remove (domain);
+
+  // Register the given aor to the give registrar
   if (!SIPEndPoint::Register (params, _aor))
     OnRegistrationFailed (aor.str (), SIP_PDU::MaxStatusCode, account.is_enabled ());
 }
@@ -594,7 +619,7 @@ void Opal::Sip::EndPoint::OnRegistered (const PString & _aor,
   std::string server;
   std::stringstream strm;
 
-  if (aor.find (uri_prefix) == std::string::npos) 
+  if (aor.find (uri_prefix) == std::string::npos)
     strm << uri_prefix << aor;
   else
     strm << aor;
@@ -614,20 +639,13 @@ void Opal::Sip::EndPoint::OnRegistered (const PString & _aor,
 
   if (loc != string::npos) {
 
-    server = aor.substr (loc+1);
-
+    server = get_aor_domain (aor);
     if (server.empty ())
       return;
 
-    if (was_registering && std::find (domains.begin (), domains.end (), server) == domains.end ()) 
-      domains.push_back (server);
-
-    if (!was_registering && std::find (domains.begin (), domains.end (), server) != domains.end ()) 
-      domains.remove (server);
-
     if (was_registering) {
-      for (std::list<std::string>::const_iterator iter = to_subscribe_uris.begin (); 
-           iter != to_subscribe_uris.end () ; ) { 
+      for (std::list<std::string>::const_iterator iter = to_subscribe_uris.begin ();
+           iter != to_subscribe_uris.end () ; ) {
 
         found = (*iter).find (server, 0);
         if (found != string::npos) {
@@ -642,8 +660,8 @@ void Opal::Sip::EndPoint::OnRegistered (const PString & _aor,
       }
     }
     else {
-      for (std::list<std::string>::const_iterator iter = subscribed_uris.begin (); 
-           iter != subscribed_uris.end () ; ) { 
+      for (std::list<std::string>::const_iterator iter = subscribed_uris.begin ();
+           iter != subscribed_uris.end () ; ) {
 
         found = (*iter).find (server, 0);
         if (found != string::npos) {
@@ -664,11 +682,12 @@ void Opal::Sip::EndPoint::OnRegistered (const PString & _aor,
     Subscribe (SIPSubscribe::MessageSummary, 3600, aor);
 
   /* Signal */
-  Ekiga::Account *account = account_core->find_account (strm.str ());
+  Opal::Account *account = bank->find_account (strm.str ());
   if (account)
-    runtime->run_in_main (sigc::bind (account->registration_event.make_slot (),
+    runtime->run_in_main (sigc::bind (sigc::ptr_fun(registration_event_in_main),
+				      account->registration_event.make_slot (),
 				      was_registering ? Ekiga::AccountCore::Registered : Ekiga::AccountCore::Unregistered,
-                                     std::string ()));
+				      std::string ()));
 }
 
 
@@ -680,7 +699,7 @@ void Opal::Sip::EndPoint::OnRegistrationFailed (const PString & _aor,
   std::string info;
   std::string aor = (const char *) _aor;
 
-  if (aor.find (uri_prefix) == std::string::npos) 
+  if (aor.find (uri_prefix) == std::string::npos)
     strm << uri_prefix << aor;
   else
     strm << aor;
@@ -776,7 +795,7 @@ void Opal::Sip::EndPoint::OnRegistrationFailed (const PString & _aor,
     break;
 
   case SIP_PDU::Failure_BadExtension:
-    // Translators : The extension we are trying to register does not exist 
+    // Translators : The extension we are trying to register does not exist
     info = _("Bad extension");
     break;
 
@@ -897,11 +916,12 @@ void Opal::Sip::EndPoint::OnRegistrationFailed (const PString & _aor,
   SIPEndPoint::OnRegistrationFailed (strm.str ().c_str (), r, wasRegistering);
 
   /* Signal */
-  Ekiga::Account *account = account_core->find_account (strm.str ());
+  Opal::Account *account = bank->find_account (strm.str ());
   if (account)
-    runtime->run_in_main (sigc::bind (account->registration_event.make_slot (),
+    runtime->run_in_main (sigc::bind (sigc::ptr_fun(registration_event_in_main),
+				      account->registration_event.make_slot (),
 				      wasRegistering ? Ekiga::AccountCore::RegistrationFailed : Ekiga::AccountCore::UnregistrationFailed,
-                                     info));
+				      info));
 }
 
 
@@ -913,7 +933,7 @@ void Opal::Sip::EndPoint::OnMWIReceived (const PString & party, OpalManager::Mes
     mwi = "0/0";
 
   /* Signal */
-  Ekiga::Account *account = account_core->find_account (party);
+  Opal::Account *account = bank->find_account (party);
   if (account)
     runtime->run_in_main (sigc::bind (account->mwi_event.make_slot (), info));
 }
@@ -927,7 +947,7 @@ bool Opal::Sip::EndPoint::OnIncomingConnection (OpalConnection &connection,
 
   if (!forward_uri.empty () && manager.get_unconditional_forward ())
     connection.ForwardCall (forward_uri);
-  else if (manager.GetCallCount () > 1) { 
+  else if (manager.GetCallCount () > 1) {
 
     if (!forward_uri.empty () && manager.get_forward_on_busy ())
       connection.ForwardCall (forward_uri);
@@ -940,7 +960,7 @@ bool Opal::Sip::EndPoint::OnIncomingConnection (OpalConnection &connection,
     Opal::Call *call = dynamic_cast<Opal::Call *> (&connection.GetCall ());
     if (call) {
 
-      if (!forward_uri.empty () && manager.get_forward_on_no_answer ()) 
+      if (!forward_uri.empty () && manager.get_forward_on_no_answer ())
         call->set_no_answer_forward (manager.get_reject_delay (), forward_uri);
       else
         call->set_reject_delay (manager.get_reject_delay ());
@@ -959,7 +979,7 @@ bool Opal::Sip::EndPoint::OnReceivedMESSAGE (OpalTransport & transport,
   PString *last = NULL;
   PString *val = NULL;
 
-  PString from = pdu.GetMIME().GetFrom();   
+  PString from = pdu.GetMIME().GetFrom();
   PINDEX j = from.Find (';');
   if (j != P_MAX_INDEX)
     from = from.Left(j); // Remove all parameters
@@ -1018,14 +1038,14 @@ SIPURL Opal::Sip::EndPoint::GetRegisteredPartyName (const SIPURL & host, const O
   }
   else {
 
-    /* If we are not registered to host, 
+    /* If we are not registered to host,
      * then use the default account as outgoing identity.
      * If we are exchanging messages with a peer on our network,
      * then do not use the default account as outgoing identity.
      */
     if (host.GetHostAddress ().GetIpAndPort (address, port) && !manager.IsLocalAddress (address)) {
 
-      Ekiga::Account *account = account_core->find_account ("ekiga.net");
+      Opal::Account *account = bank->find_account ("Ekiga.net");
 
       if (account)
         return SIPURL ("\"" + GetDefaultDisplayName () + "\" <" + PString(account->get_aor ()) + ">");
@@ -1033,13 +1053,13 @@ SIPURL Opal::Sip::EndPoint::GetRegisteredPartyName (const SIPURL & host, const O
   }
 
   /* As a last resort, ie not registered to host, no default account or
-   * dialog with a local peer, then use the local address 
+   * dialog with a local peer, then use the local address
    */
   return GetDefaultRegisteredPartyName (transport);
 }
 
 
-void 
+void
 Opal::Sip::EndPoint::OnPresenceInfoReceived (const PString & user,
                                              const PString & basic,
                                              const PString & note)
@@ -1065,10 +1085,10 @@ Opal::Sip::EndPoint::OnPresenceInfoReceived (const PString & user,
     else if (s.Find ("Ringing") != P_MAX_INDEX)
       presence = "ringing";
     else if (s.Find ("dnd") != P_MAX_INDEX
-             || s.Find ("Do Not Disturb") != P_MAX_INDEX) 
+             || s.Find ("Do Not Disturb") != P_MAX_INDEX)
       presence = "dnd";
 
-    else if (s.Find ("Free For Chat") != P_MAX_INDEX) 
+    else if (s.Find ("Free For Chat") != P_MAX_INDEX)
       presence = "freeforchat";
 
     if ((j = s.Find (" - ")) != P_MAX_INDEX)
@@ -1078,30 +1098,32 @@ Opal::Sip::EndPoint::OnPresenceInfoReceived (const PString & user,
   SIPURL sip_uri = SIPURL (user);
   sip_uri.Sanitise (SIPURL::ExternalURI);
   std::string _uri = sip_uri.AsString ();
-  std::string old_presence = uri_presences[_uri].first;
-  std::string old_status = uri_presences[_uri].second;
+  std::string old_presence = presence_infos[_uri].presence;
+  std::string old_status = presence_infos[_uri].status;
 
   // If first notification, and no information, then we are offline
   if (presence == "unknown" && old_presence.empty ())
     presence = "offline";
 
   // If presence change, then signal it to the various components
-  // If presence is unknown (notification with empty body), and it is not the 
-  // first notification, and we can conclude it is a ping back from the server 
+  // If presence is unknown (notification with empty body), and it is not the
+  // first notification, and we can conclude it is a ping back from the server
   // to indicate the presence status did not change, hence we do nothing.
   if (presence != "unknown" && (old_presence != presence || old_status != status)) {
-    uri_presences[_uri] = std::pair<std::string, std::string> (presence, status);
-    runtime->run_in_main (sigc::bind (sigc::ptr_fun (presence_status_in_main), this, _uri, presence, status));
+    presence_infos[_uri].presence = presence;
+    presence_infos[_uri].status = status;
+    runtime->run_in_main (sigc::bind (sigc::ptr_fun (presence_status_in_main), this, _uri, presence_infos[_uri].presence, presence_infos[_uri].status));
   }
 }
 
 
-void 
+void
 Opal::Sip::EndPoint::OnDialogInfoReceived (const SIPDialogNotification & info)
 {
-  gchar* status = NULL;
+  gchar* _status = NULL;
+  std::string status;
   std::string presence;
-  PString uri = info.m_entity;
+  std::string uri = (const char *) info.m_entity;
   PString remote_uri = info.m_remote.m_identity;
   PString remote_display_name = info.m_remote.m_display.IsEmpty () ? remote_uri : info.m_remote.m_display;
 
@@ -1109,17 +1131,19 @@ Opal::Sip::EndPoint::OnDialogInfoReceived (const SIPDialogNotification & info)
     case SIPDialogNotification::Proceeding:
     case SIPDialogNotification::Early:
       if (!remote_display_name.IsEmpty ())
-        status = g_strdup_printf (_("Incoming call from %s"), (const char *) remote_display_name);
+        _status = g_strdup_printf (_("Incoming call from %s"), (const char *) remote_display_name);
       else
-        status = g_strdup_printf (_("Incoming call"));
+        _status = g_strdup_printf (_("Incoming call"));
+      status = _status;
       presence = "ringing";
       break;
     case SIPDialogNotification::Confirmed:
       if (!remote_display_name.IsEmpty ())
-        status = g_strdup_printf (_("In a call with %s"), (const char *) remote_display_name);
+        _status = g_strdup_printf (_("In a call with %s"), (const char *) remote_display_name);
       else
-        status = g_strdup_printf (_("In a call"));
+        _status = g_strdup_printf (_("In a call"));
       presence = "inacall";
+      status = _status;
       break;
     default:
     case SIPDialogNotification::Trying:
@@ -1127,10 +1151,13 @@ Opal::Sip::EndPoint::OnDialogInfoReceived (const SIPDialogNotification & info)
       break;
   }
 
-  if (status)
-    runtime->run_in_main (sigc::bind (sigc::ptr_fun (presence_status_in_main), this, uri, presence, status));
+  dialog_infos[uri].presence = presence;
+  dialog_infos[uri].status = status;
+
+  if (_status)
+    runtime->run_in_main (sigc::bind (sigc::ptr_fun (presence_status_in_main), this, uri, dialog_infos[uri].presence, dialog_infos[uri].status));
   else
-    runtime->run_in_main (sigc::bind (sigc::ptr_fun (presence_status_in_main), this, uri, uri_presences[uri].first, uri_presences[uri].second));
+    runtime->run_in_main (sigc::bind (sigc::ptr_fun (presence_status_in_main), this, uri, presence_infos[uri].presence, presence_infos[uri].status));
 }
 
 
