@@ -40,7 +40,10 @@
 #include "engine.h"
 
 #include "services.h"
+#include "kickstart.h"
 
+#include "notification-core.h"
+#include "plugin-core.h"
 #include "presence-core.h"
 #include "account-core.h"
 #include "contact-core.h"
@@ -76,6 +79,9 @@
 
 #ifdef HAVE_DBUS
 #include "hal-main-dbus.h"
+#ifdef HAVE_GNOME
+#include "gnome-session-main.h"
+#endif
 #endif
 
 #include "opal-main.h"
@@ -93,6 +99,10 @@
 #include "ldap-main.h"
 #endif
 
+#ifdef HAVE_NOTIFY
+#include "libnotify-main.h"
+#endif
+
 #ifdef HAVE_GSTREAMER
 #include "gst-main.h"
 #endif
@@ -110,6 +120,11 @@
 #include "resource-list-main.h"
 #endif
 
+#define DEBUG_STARTUP 0
+
+#if DEBUG_STARTUP
+#include <iostream>
+#endif
 
 static Ekiga::ServiceCore *service_core = NULL;
 
@@ -119,6 +134,10 @@ engine_init (int argc,
              Ekiga::Runtime* runtime)
 {
   service_core = new Ekiga::ServiceCore;
+  Ekiga::KickStart kickstart;
+
+
+  service_core->add (gmref_ptr<Ekiga::Service>(new Ekiga::NotificationCore));
 
   /* VideoInputCore depends on VideoOutputCore and must this              *
    * be constructed thereafter                                      */
@@ -145,15 +164,16 @@ engine_init (int argc,
   service_core->add (account_core);
   service_core->add (contact_core);
   service_core->add (chat_core);
-  service_core->add (videooutput_core);
   service_core->add (videoinput_core);
-  service_core->add (audiooutput_core);
+  service_core->add (videooutput_core);
   service_core->add (audioinput_core);
+  service_core->add (audiooutput_core);
   service_core->add (hal_core);
   service_core->add (call_core);
 
   if (!gmconf_personal_details_init (*service_core, &argc, &argv)) {
     delete service_core;
+    service_core = NULL;
     return;
   }
 
@@ -163,130 +183,106 @@ engine_init (int argc,
 #ifndef WIN32
   if (!videooutput_x_init (*service_core, &argc, &argv)) {
     delete service_core;
+    service_core = NULL;
     return;
   }
 #endif
 
-#ifdef HAVE_XCAP
-  xcap_init (*service_core);
-#endif
-
 #ifdef HAVE_DX
   if (!videooutput_dx_init (*service_core, &argc, &argv)) {
     delete service_core;
+    service_core = NULL;
     return;
   }
 #endif
 
   if (!videoinput_mlogo_init (*service_core, &argc, &argv)) {
     delete service_core;
+    service_core = NULL;
     return;
   }
 
+#ifdef HAVE_NOTIFY
+  libnotify_init (kickstart);
+#endif
+
 #ifdef HAVE_GSTREAMER
   (void)gstreamer_init (*service_core, &argc, &argv);
 #endif
 
-  if (!audioinput_null_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  audioinput_null_init (kickstart);
 
-  if (!audiooutput_null_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  audiooutput_null_init (kickstart);
 
-  if (!videoinput_ptlib_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  videoinput_ptlib_init (kickstart);
 
-  if (!audioinput_ptlib_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  audioinput_ptlib_init (kickstart);
 
-  if (!audiooutput_ptlib_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  audiooutput_ptlib_init (kickstart);
 
 #ifdef HAVE_DBUS
-  if (!hal_dbus_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  hal_dbus_init (kickstart);
 #endif
 
-  if (!opal_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  opal_init (kickstart);
 
 #ifdef HAVE_AVAHI
-  if (!avahi_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
-
-  if (!avahi_publisher_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  avahi_init (kickstart);
+  avahi_publisher_init (kickstart);
 #endif
 
 #ifdef HAVE_EDS
-  if (!evolution_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  evolution_init (kickstart);
 #endif
 
 #ifdef HAVE_LDAP
-  if (!ldap_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  ldap_init (kickstart);
+#endif
+
+#ifdef HAVE_GNOME
+#ifdef HAVE_DBUS
+  gnomesession_init (kickstart);
+#endif
 #endif
 
 #ifdef HAVE_KDE
-  (void)kde_init (*service_core, &argc, &argv);
+  kde_init (kickstart);
 #endif
 
 #ifdef HAVE_KAB
-  (void)kab_init (*service_core, &argc, &argv);
+  kab_init (kickstart);
 #endif
 
 #ifdef HAVE_XCAP
-  resource_list_init (*service_core, &argc, &argv);
+  xcap_init (kickstart);
+  resource_list_init (kickstart);
 #endif
 
-  if (!history_init (*service_core, &argc, &argv)) {
+  history_init (kickstart);
 
-    delete service_core;
-    return;
-  }
+  /* FIXME: this one should go away -- but if I don't put it here, the GUI
+   * doesn't work correctly */
+  kickstart.kick (*service_core, &argc, &argv);
 
   if (!gtk_core_init (*service_core, &argc, &argv)) {
     delete service_core;
+    service_core = NULL;
     return;
   }
 
   if (!gtk_frontend_init (*service_core, &argc, &argv)) {
     delete service_core;
+    service_core = NULL;
     return;
   }
 
-  if (!local_roster_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  local_roster_init (kickstart);
 
-  if (!local_roster_bridge_init (*service_core, &argc, &argv)) {
-    delete service_core;
-    return;
-  }
+  local_roster_bridge_init (kickstart);
+
+  plugin_init (kickstart);
+
+  kickstart.kick (*service_core, &argc, &argv);
 
   videooutput_core->setup_conf_bridge();
   videoinput_core->setup_conf_bridge();
@@ -302,6 +298,11 @@ engine_init (int argc,
   conn = hal_core->audioinput_device_removed.connect (sigc::mem_fun (*audioinput_core, &Ekiga::AudioInputCore::remove_device));
   // std::vector<sigc::connection> connections;
   //connections.push_back (conn);
+
+#if DEBUG_STARTUP
+  std::cout << "Here is what ekiga is made of for this run :" << std::endl;
+  service_core->dump (std::cout);
+#endif
 }
 
 
