@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,12 +35,11 @@
  *   			    manipulate accounts.
  */
 
-#include "config.h"
-
 #include "accounts.h"
 
 #include "account.h"
 #include "bank.h"
+#include "opal-bank.h"
 #include "account-core.h"
 #include "audiooutput-core.h"
 
@@ -49,15 +48,11 @@
 #include "main.h"
 #include "preferences.h"
 
-#include "manager.h"
-#include "sip-endpoint.h"
-#include "h323-endpoint.h"
-#include "ekiga.h"
-
 #include "gmconf.h"
 #include "gmdialog.h"
 
 #include "services.h"
+#include "menu-builder-tools.h"
 #include "menu-builder-gtk.h"
 #include "form-dialog-gtk.h"
 
@@ -262,20 +257,17 @@ on_registration_event (const Ekiga::Account & account,
 
 
 static void 
-on_mwi_event (const Ekiga::Account & account,
+on_mwi_event (const Ekiga::Account* account,
               std::string mwi,
               gpointer self)
 {
-  GmAccountsWindow *aw = NULL;
-
-  aw = gm_aw_get_aw (GTK_WIDGET (self));
-  Ekiga::AudioOutputCore *audiooutput_core = dynamic_cast<Ekiga::AudioOutputCore *> (aw->core.get ("audiooutput-core"));
-
-  if (gm_accounts_window_update_account_state (GTK_WIDGET (self), false, account, NULL, mwi.c_str ())) {
+  if (gm_accounts_window_update_account_state (GTK_WIDGET (self), false, *account, NULL, mwi.c_str ())) {
 
     std::string::size_type loc = mwi.find ("/", 0);
     if (loc != std::string::npos) {
 
+      GmAccountsWindow *aw = gm_aw_get_aw (GTK_WIDGET (self));
+      gmref_ptr<Ekiga::AudioOutputCore> audiooutput_core = aw->core.get ("audiooutput-core");
       std::stringstream new_messages;
       int i;
       new_messages << mwi.substr (0, loc);
@@ -306,7 +298,8 @@ populate_menu (GtkWidget *window)
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (aw->accounts_list));
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (aw->accounts_list));
 
-  Ekiga::AccountCore *account_core = dynamic_cast<Ekiga::AccountCore *> (aw->core.get ("account-core"));
+  gmref_ptr<Ekiga::AccountCore> account_core
+    = aw->core.get ("account-core");
 
   if (account_core->populate_menu (builder)) {
     item = gtk_separator_menu_item_new ();
@@ -327,7 +320,7 @@ populate_menu (GtkWidget *window)
   item = gtk_image_menu_item_new_from_stock (GTK_STOCK_CLOSE, aw->accel);
   gtk_menu_shell_append (GTK_MENU_SHELL (builder.menu), item);
   g_signal_connect_swapped (G_OBJECT (item), "activate",
-                            GTK_SIGNAL_FUNC (gtk_widget_hide),
+                            G_CALLBACK (gtk_widget_hide),
                             (gpointer) window);
 
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (aw->menu_item_core),
@@ -357,9 +350,7 @@ account_clicked_cb (G_GNUC_UNUSED GtkWidget *w,
   tree_view = GTK_TREE_VIEW (aw->accounts_list);
   model = gtk_tree_view_get_model (tree_view);
 
-  if (event->type == GDK_BUTTON_PRESS || event->type == GDK_KEY_PRESS) {
-
-    populate_menu (GTK_WIDGET (data));
+  if (event->type == GDK_BUTTON_PRESS || event->type == GDK_KEY_PRESS || event->type == GDK_2BUTTON_PRESS) {
 
     if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (tree_view),
                                        (gint) event->x, (gint) event->y,
@@ -371,27 +362,40 @@ account_clicked_cb (G_GNUC_UNUSED GtkWidget *w,
                             COLUMN_ACCOUNT, &account,
                             -1);
 
-        if (event->button == 3) {
-
-          MenuBuilderGtk builder;
-          account->populate_menu (builder);
-          if (!builder.empty ()) {
-
-            gtk_widget_show_all (builder.menu);
-            gtk_menu_popup (GTK_MENU (builder.menu), NULL, NULL,
-                            NULL, NULL, event->button, event->time);
-            g_signal_connect (G_OBJECT (builder.menu), "hide",
-                              GTK_SIGNAL_FUNC (g_object_unref),
-                              (gpointer) builder.menu);
-          }
-          g_object_ref_sink (G_OBJECT (builder.menu));
-        }
+        gtk_tree_path_free (path);
       }
-
-      gtk_tree_path_free (path);
     }
   }
 
+  if (account == NULL)
+    return FALSE;
+
+  if (event->type == GDK_BUTTON_PRESS || event->type == GDK_KEY_PRESS) {
+
+    populate_menu (GTK_WIDGET (data));
+
+    if (event->button == 3) {
+
+      MenuBuilderGtk builder;
+      account->populate_menu (builder);
+      if (!builder.empty ()) {
+
+        gtk_widget_show_all (builder.menu);
+        gtk_menu_popup (GTK_MENU (builder.menu), NULL, NULL,
+                        NULL, NULL, event->button, event->time);
+        g_signal_connect (G_OBJECT (builder.menu), "hide",
+                          G_CALLBACK (g_object_unref),
+                          (gpointer) builder.menu);
+      }
+      g_object_ref_sink (G_OBJECT (builder.menu));
+    }
+  }
+  else if (event->type == GDK_2BUTTON_PRESS) {
+
+    Ekiga::TriggerMenuBuilder builder;
+    account->populate_menu (builder);
+  }
+
   return TRUE;
 }
 
@@ -765,14 +769,17 @@ gm_accounts_window_new (Ekiga::ServiceCore &core)
   /* Engine Signals callbacks */
   // FIXME sigc::connection conn;
 
-  Ekiga::AccountCore *account_core = dynamic_cast<Ekiga::AccountCore *> (core.get ("account-core"));
+  gmref_ptr<Ekiga::AccountCore> account_core = core.get ("account-core");
+  gmref_ptr<Opal::Bank> bank = core.get ("opal-account-store");
   account_core->bank_added.connect (sigc::bind (sigc::ptr_fun (on_bank_added), window));
   account_core->account_added.connect (sigc::bind (sigc::ptr_fun (on_account_added), window));
   account_core->account_updated.connect (sigc::bind (sigc::ptr_fun (on_account_updated), window));
   account_core->account_removed.connect (sigc::bind (sigc::ptr_fun (on_account_removed), window));
   account_core->questions.add_handler (sigc::bind (sigc::ptr_fun (on_handle_questions), (gpointer) window));
   account_core->registration_event.connect (sigc::bind (sigc::ptr_fun (on_registration_event), (gpointer) window));
-  account_core->mwi_event.connect (sigc::bind (sigc::ptr_fun (on_mwi_event), (gpointer) window));
+  bank->mwi_event.connect (sigc::bind (sigc::ptr_fun (on_mwi_event), (gpointer) window));
+
+  account_core->visit_banks (sigc::bind_return (sigc::bind (sigc::ptr_fun (on_bank_added), window), true));
   
   return window;
 }
