@@ -88,6 +88,8 @@ struct _EkigaAssistantPrivate
 
   GtkWidget *video_device;
 
+  gint last_active_page;
+
   GtkListStore *summary_model;
   std::vector<sigc::connection> connections;
 };
@@ -328,7 +330,7 @@ create_welcome_page (EkigaAssistant *assistant)
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
   gtk_widget_show (label);
   gtk_assistant_append_page (GTK_ASSISTANT (assistant), label);
-  gtk_assistant_set_page_title (GTK_ASSISTANT (assistant), label, _("Welcome in Ekiga"));
+  gtk_assistant_set_page_title (GTK_ASSISTANT (assistant), label, _("Welcome to Ekiga"));
   gtk_assistant_set_page_type (GTK_ASSISTANT (assistant), label, GTK_ASSISTANT_PAGE_INTRO);
   gtk_assistant_set_page_header_image (GTK_ASSISTANT (assistant), label, assistant->priv->icon);
   gtk_assistant_set_page_complete (GTK_ASSISTANT (assistant), label, TRUE);
@@ -633,9 +635,8 @@ create_ekiga_net_page (EkigaAssistant *assistant)
 static void
 prepare_ekiga_net_page (EkigaAssistant *assistant)
 {
-  gmref_ptr<Ekiga::AccountCore> account_core
-    = assistant->priv->core->get ("account-core");
-  Ekiga::Account *account = account_core->find_account ("ekiga.net");
+  gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
+  Opal::Account* account = bank->find_account ("ekiga.net");
 
   if (account && !account->get_username ().empty ())
     gtk_entry_set_text (GTK_ENTRY (assistant->priv->username), account->get_username ().c_str ());
@@ -651,21 +652,15 @@ prepare_ekiga_net_page (EkigaAssistant *assistant)
 static void
 apply_ekiga_net_page (EkigaAssistant *assistant)
 {
-  gmref_ptr<Ekiga::AccountCore> account_core
-    = assistant->priv->core->get ("account-core");
-
-  /* Some specific Opal stuff for the Ekiga.net account */
-  gmref_ptr<Opal::Bank> opal_bank =
-    assistant->priv->core->get ("opal-account-store");
-  Opal::Account* account = dynamic_cast<Opal::Account*>(account_core->find_account ("ekiga.net"));
-
+  gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
+  Opal::Account* account = bank->find_account ("ekiga.net");
   bool new_account = (account == NULL);
 
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (assistant->priv->skip_ekiga_net))) {
 	if (new_account)
-	  opal_bank->new_account (Opal::Account::Ekiga,
-							  gtk_entry_get_text (GTK_ENTRY (assistant->priv->username)),
-							  gtk_entry_get_text (GTK_ENTRY (assistant->priv->password)));
+	  bank->new_account (Opal::Account::Ekiga,
+			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->username)),
+			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->password)));
 	else
 	  account->set_authentication_settings (gtk_entry_get_text (GTK_ENTRY (assistant->priv->username)),
 											gtk_entry_get_text (GTK_ENTRY (assistant->priv->password)));
@@ -784,9 +779,8 @@ create_ekiga_out_page (EkigaAssistant *assistant)
 static void
 prepare_ekiga_out_page (EkigaAssistant *assistant)
 {
-  gmref_ptr<Ekiga::AccountCore> account_core
-    = assistant->priv->core->get ("account-core");
-  Ekiga::Account *account = account_core->find_account ("sip.diamondcard.us");
+  gmref_ptr<Opal::Bank> account_core = assistant->priv->core->get ("opal-account-store");
+  Opal::Account* account = account_core->find_account ("sip.diamondcard.us");
 
   if (account && !account->get_username ().empty ())
     gtk_entry_set_text (GTK_ENTRY (assistant->priv->dusername), account->get_username ().c_str ());
@@ -802,24 +796,19 @@ prepare_ekiga_out_page (EkigaAssistant *assistant)
 static void
 apply_ekiga_out_page (EkigaAssistant *assistant)
 {
-  gmref_ptr<Ekiga::AccountCore> account_core
-    = assistant->priv->core->get ("account-core");
-
   /* Some specific Opal stuff for the Ekiga.net account */
-  gmref_ptr<Opal::Bank> opal_bank
-    = assistant->priv->core->get ("opal-account-store");
-  Opal::Account* account = dynamic_cast<Opal::Account*> (account_core->find_account ("sip.diamondcard.us"));
-
+  gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
+  Opal::Account* account = bank->find_account ("sip.diamondcard.us");
   bool new_account = (account == NULL);
 
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (assistant->priv->skip_ekiga_out))) {
 	if (new_account)
-	  opal_bank->new_account (Opal::Account::DiamondCard,
-							  gtk_entry_get_text (GTK_ENTRY (assistant->priv->dusername)),
-							  gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
+	  bank->new_account (Opal::Account::DiamondCard,
+			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->dusername)),
+			     gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
 	else
 	  account->set_authentication_settings (gtk_entry_get_text (GTK_ENTRY (assistant->priv->dusername)),
-											gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
+						gtk_entry_get_text (GTK_ENTRY (assistant->priv->dpassword)));
   }
 }
 
@@ -1477,6 +1466,7 @@ ekiga_assistant_init (EkigaAssistant *assistant)
   gtk_window_set_position (GTK_WINDOW (assistant), GTK_WIN_POS_CENTER);
   gtk_container_set_border_width (GTK_CONTAINER (assistant), 12);
 
+  assistant->priv->last_active_page = 0;
   assistant->priv->icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
                                                     "ekiga", 48,
                                                     (GtkIconLookupFlags) 0, NULL);
@@ -1500,7 +1490,8 @@ ekiga_assistant_prepare (GtkAssistant *gtkassistant,
                          GtkWidget    *page)
 {
   EkigaAssistant *assistant = EKIGA_ASSISTANT (gtkassistant);
-  gchar *title;
+  gchar *title = NULL;
+  bool forward = false;
 
   title = g_strdup_printf (_("Ekiga Configuration Assistant (%d of %d)"),
                            gtk_assistant_get_current_page (gtkassistant) + 1,
@@ -1509,6 +1500,13 @@ ekiga_assistant_prepare (GtkAssistant *gtkassistant,
   gtk_window_set_title (GTK_WINDOW (assistant), title);
   g_free (title);
 
+  if (assistant->priv->last_active_page < gtk_assistant_get_current_page (gtkassistant))
+    forward = true;
+  assistant->priv->last_active_page = gtk_assistant_get_current_page (gtkassistant);
+
+  if (!forward)
+    return;
+
   if (page == assistant->priv->personal_data_page) {
     prepare_personal_data_page (assistant);
     return;
