@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,15 +43,6 @@
 #include "common.h"
 
 
-
-/* DESCRIPTION  :  This callback is called when the user chooses to save.
- * BEHAVIOR     :  Saves the picture in the current video stream in a file.
- * PRE          :  /
- */
-void save_callback (GtkWidget *widget,
-		    gpointer data);
-
-
 /* DESCRIPTION  :  Simple wrapper that will call gnomemeeting_hide_window.
  * BEHAVIOR     :  Calls gnomemeeting_window_hide.
  * PRE          :  /
@@ -70,6 +61,11 @@ gboolean delete_window_cb (GtkWidget *widget,
 void show_window_cb (GtkWidget *widget,
 		     gpointer data);
 
+void show_assistant_window_cb (GtkWidget *widget,
+                               gpointer   data);
+
+void show_prefs_window_cb (GtkWidget *widget,
+			   gpointer   data);
 
 /* DESCRIPTION  :  Simple wrapper that will call gnomemeeting_window_hide.
  * BEHAVIOR     :  Calls gnomemeeting_window_hide.
@@ -80,24 +76,6 @@ void hide_window_cb (GtkWidget *widget,
 		     gpointer data);
 
 
-/* DESCRIPTION  :  This callback is called when the user choose to establish
- *                 a connection.
- * BEHAVIOR     :  Call the remote endpoint or accept the incoming call.
- * PRE          :  /
- */
-void connect_cb (GtkWidget *widget,
-		 gpointer data);
-
-
-/* DESCRIPTION  :  This callback is called when the user choose to stop
- *                 a connection.
- * BEHAVIOR     :  Do not accept the incoming call or stops the current call.
- * PRE          :  /
- */
-void disconnect_cb (GtkWidget *widget,
-		    gpointer data);
-
-
 /* DESCRIPTION  :  This callback is called when the user chooses to open
  *                 the about window.
  * BEHAVIOR     :  Open the about window.
@@ -124,24 +102,6 @@ void quit_callback (GtkWidget *widget,
 		    gpointer data);
 
 
-/* DESCRIPTION  :  This callback is called to compare urls and see if they
- * 		   match.
- * BEHAVIOR     :  It returns TRUE if the given key matches an URL OR a last
- * 		   name or first name in the list store of the completion 
- * 		   entry AND if the matched URL was not already returned
- * 		   previously.
- * 		   2 SIP/H323 URLs match if they begin by
- * 		   the same chars, and 2 CALLTO URLs with a valid email
- * 		   address on an ILS server match if the key matches an email
- * 		   address or the begin of a server. 
- * PRE          :  data is a valid pointer to the list store.
- */
-gboolean entry_completion_url_match_cb (GtkEntryCompletion *completion,
-					const gchar *key,
-					GtkTreeIter *iter,
-					gpointer data);
-
-
 /* DESCRIPTION  :  This callback is called when the user toggles a
  *                 connect button.
  * BEHAVIOR     :  Connect if there is a connect URL in the URL bar and if the
